Index: include/asterisk/calendar.h
===================================================================
--- include/asterisk/calendar.h	(revision 281686)
+++ include/asterisk/calendar.h	(working copy)
@@ -95,7 +95,9 @@
 		AST_STRING_FIELD(organizer);
 		AST_STRING_FIELD(location);
 		AST_STRING_FIELD(uid);
+		AST_STRING_FIELD(categories);
 	);
+	int priority;        /*!< Priority of event */
 	struct ast_calendar *owner;   /*!< The calendar that owns this event */
 	time_t start;        /*!< Start of event (UTC) */
 	time_t end;          /*!< End of event (UTC) */
Index: res/res_calendar.c
===================================================================
--- res/res_calendar.c	(revision 281686)
+++ res/res_calendar.c	(working copy)
@@ -65,6 +65,8 @@
 					<enum name="description"><para>The text description of the event</para></enum>
 					<enum name="organizer"><para>The organizer of the event</para></enum>
 					<enum name="location"><para>The location of the eventt</para></enum>
+					<enum name="categories"><para>The categories of the event</para></enum>
+					<enum name="priority"><para>The priority of the event</para></enum>
 					<enum name="calendar"><para>The name of the calendar associated with the event</para></enum>
 					<enum name="uid"><para>The unique identifier for this event</para></enum>
 					<enum name="start"><para>The start time of the event</para></enum>
@@ -112,6 +114,8 @@
 					<enum name="description"><para>The full event description</para></enum>
 					<enum name="organizer"><para>The event organizer</para></enum>
 					<enum name="location"><para>The event location</para></enum>
+					<enum name="categories"><para>The categories of the event</para></enum>
+					<enum name="priority"><para>The priority of the event</para></enum>
 					<enum name="calendar"><para>The name of the calendar associted with the event</para></enum>
 					<enum name="uid"><para>The unique identifier for the event</para></enum>
 					<enum name="start"><para>The start time of the event (in seconds since epoch)</para></enum>
@@ -142,6 +146,8 @@
 					<enum name="description"><para>The full event description</para></enum>
 					<enum name="organizer"><para>The event organizer</para></enum>
 					<enum name="location"><para>The event location</para></enum>
+					<enum name="categories"><para>The categories of the event</para></enum>
+					<enum name="priority"><para>The priority of the event</para></enum>
 					<enum name="uid"><para>The unique identifier for the event</para></enum>
 					<enum name="start"><para>The start time of the event (in seconds since epoch)</para></enum>
 					<enum name="end"><para>The end time of the event (in seconds since epoch)</para></enum>
@@ -786,6 +792,8 @@
 	ast_string_field_set(dst, organizer, src->organizer);
 	ast_string_field_set(dst, location, src->location);
 	ast_string_field_set(dst, uid, src->uid);
+	ast_string_field_set(dst, categories, src->categories);
+	dst->priority = src->priority;
 	dst->owner = src->owner;
 	dst->start = src->start;
 	dst->end = src->end;
@@ -1228,6 +1236,10 @@
 			ast_copy_string(buf, entry->event->organizer, len);
 		} else if (!strcasecmp(args.field, "location")) {
 			ast_copy_string(buf, entry->event->location, len);
+		} else if (!strcasecmp(args.field, "categories")) {
+			ast_copy_string(buf, entry->event->categories, len);
+		} else if (!strcasecmp(args.field, "priority")) {
+			snprintf(buf, len, "%d", entry->event->priority);
 		} else if (!strcasecmp(args.field, "calendar")) {
 			ast_copy_string(buf, entry->event->owner->name, len);
 		} else if (!strcasecmp(args.field, "uid")) {
@@ -1313,6 +1325,10 @@
 			ast_string_field_set(event, organizer, values.value[j]);
 		} else if (!strcasecmp(fields.field[i], "location")) {
 			ast_string_field_set(event, location, values.value[j]);
+		} else if (!strcasecmp(fields.field[i], "categories")) {
+			ast_string_field_set(event, categories, values.value[j]);
+		} else if (!strcasecmp(fields.field[i], "priority")) {
+			event->priority = atoi(values.value[j]);
 		} else if (!strcasecmp(fields.field[i], "uid")) {
 			ast_string_field_set(event, uid, values.value[j]);
 		} else if (!strcasecmp(fields.field[i], "start")) {
@@ -1468,6 +1484,8 @@
 		ast_cli(a->fd, FORMAT2, "Description", event->description);
 		ast_cli(a->fd, FORMAT2, "Organizer", event->organizer);
 		ast_cli(a->fd, FORMAT2, "Location", event->location);
+		ast_cli(a->fd, FORMAT2, "Cartegories", event->categories);
+		ast_cli(a->fd, "%-12.12s: %d\n", "Priority", event->priority);
 		ast_cli(a->fd, FORMAT2, "UID", event->uid);
 		ast_cli(a->fd, FORMAT2, "Start", epoch_to_string(buf, sizeof(buf), event->start));
 		ast_cli(a->fd, FORMAT2, "End", epoch_to_string(buf, sizeof(buf), event->end));
@@ -1539,6 +1557,10 @@
 		ast_copy_string(buf, event->organizer, len);
 	} else if (!strcasecmp(data, "location")) {
 		ast_copy_string(buf, event->location, len);
+	} else if (!strcasecmp(data, "categories")) {
+		ast_copy_string(buf, event->categories, len);
+	} else if (!strcasecmp(data, "priority")) {
+		snprintf(buf, len, "%d", event->priority);
 	} else if (!strcasecmp(data, "calendar")) {
 		ast_copy_string(buf, event->owner->name, len);
 	} else if (!strcasecmp(data, "uid")) {
Index: res/res_calendar_icalendar.c
===================================================================
--- res/res_calendar_icalendar.c	(revision 281686)
+++ res/res_calendar_icalendar.c	(working copy)
@@ -224,6 +224,14 @@
 		ast_string_field_set(event, location, icalproperty_get_value_as_string(prop));
 	}
 
+	if ((prop = icalcomponent_get_first_property(comp, ICAL_CATEGORIES_PROPERTY))) {
+		ast_string_field_set(event, categories, icalproperty_get_value_as_string(prop));
+	}
+
+	if ((prop = icalcomponent_get_first_property(comp, ICAL_PRIORITY_PROPERTY))) {
+		event->priority = icalvalue_get_integer(icalproperty_get_value(prop));
+	}
+
 	if ((prop = icalcomponent_get_first_property(comp, ICAL_UID_PROPERTY))) {
 		ast_string_field_set(event, uid, icalproperty_get_value_as_string(prop));
 	} else {
Index: res/res_calendar_caldav.c
===================================================================
--- res/res_calendar_caldav.c	(revision 281686)
+++ res/res_calendar_caldav.c	(working copy)
@@ -216,6 +216,12 @@
 	if (!ast_strlen_zero(event->location)) {
 		icalcomponent_add_property(icalevent, icalproperty_new_location(event->location));
 	}
+	if (!ast_strlen_zero(event->categories)) {
+		icalcomponent_add_property(icalevent, icalproperty_new_categories(event->categories));
+	}
+	if (event->priority > 0) {
+		icalcomponent_add_property(icalevent, icalproperty_new_priority(event->priority));
+	}
 
 	switch (event->busy_state) {
 	case AST_CALENDAR_BS_BUSY:
@@ -365,6 +371,14 @@
 		ast_string_field_set(event, location, icalproperty_get_value_as_string(prop));
 	}
 
+	if ((prop = icalcomponent_get_first_property(comp, ICAL_CATEGORIES_PROPERTY))) {
+		ast_string_field_set(event, categories, icalproperty_get_value_as_string(prop));
+	}
+
+	if ((prop = icalcomponent_get_first_property(comp, ICAL_PRIORITY_PROPERTY))) {
+		event->priority = icalvalue_get_integer(icalproperty_get_value(prop));
+	}
+
 	if ((prop = icalcomponent_get_first_property(comp, ICAL_UID_PROPERTY))) {
 		ast_string_field_set(event, uid, icalproperty_get_value_as_string(prop));
 	} else {
